# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](http://keepachangelog.com/en/1.0.0/)
and this project adheres to [Semantic Versioning](http://semver.org/spec/v2.0.0.html).

## v1.0.1
增加参数 prefix 和 out
-p 用于指定 thrift 文件的前缀，前缀对应的路径不会出现在输出的文件中
-o 用于指定输出文件的路径，输出文件包括 thrift 文件、pyi 文件和 __init__.py


## v1.0.2
- Exception 收敛至 Thrift2pyiException
- 优化相对引用

## v1.0.3
- 支持 union

## v2.0.0
- 维护权转移与新包名：pyi4thrift
- 仅支持 Python >= 3.9
- packaging 迁移到 pyproject.toml + hatchling
- src/ 目录结构

## v2.1.0
- 解析器切换为 Lark，移除 pypeg2 依赖
- include 模块解析兼容性修复
